pub fn pan_timeline_by(
geo: &TimelineGeometry,
start_pan_ms: f64,
delta_px: f64,
) -> TimelineViewportExpand description
Compute the new viewport after dragging the track by delta_px pixels (zoom unchanged).
pub fn pan_timeline_by(
geo: &TimelineGeometry,
start_pan_ms: f64,
delta_px: f64,
) -> TimelineViewportCompute the new viewport after dragging the track by delta_px pixels (zoom unchanged).